@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocosi::ReadLine::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocosi::ReadLine::VERSION = '0.02';
+  $App::Pocosi::ReadLine::VERSION = '0.03';
 }
 
 use strict;
@@ -112,6 +112,8 @@ sub got_user_input {
             };
             if (my $err = $@) {
                 chomp $err;
+                my $our_file = __FILE__;
+                $err =~ s{ at \Q$our_file\E line [0-9]+\.$}{};
                 warn $err, "\n";
             }
         }
